import { Injectable } from '@nestjs/common';
import { DateTime, TimeZone } from 'timezonecomplete';
import { TimeConverterPort } from '../core/application/ports/time-converter.port';

@Injectable()
export class TimeConverter implements TimeConverterPort {
  private readonly BASE_DATE = '1970-01-01';

  localStringTimeToUtcStringTime = (time: string, timezone: string): string => {
    try {
      if (!time || !timezone) throw new Error();
      return new DateTime(`${this.BASE_DATE}T${time}`, TimeZone.zone(timezone))
        .convert(TimeZone.zone('UTC'))
        .format('HH:mm');
    } catch (e) {
      return undefined;
    }
  };

  localStringDateTimeToUtcDate = (
    date: string,
    time: string,
    timezone: string,
    dst = true,
  ): Date => {
    try {
      if (!time || !timezone) throw new Error();
      return new DateTime(`${date}T${time}`, TimeZone.zone(timezone, dst))
        .convert(TimeZone.zone('UTC'))
        .toDate();
    } catch (e) {
      return undefined;
    }
  };

  utcDatetimeToLocalTime = (isoString: string, timezone: string): string => {
    try {
      return new DateTime(isoString)
        .convert(TimeZone.zone(timezone))
        .toString()
        .split('T')[1]
        .substring(0, 5);
    } catch (e) {
      return undefined;
    }
  };
}
