import { TimeConverter } from '@modules/ad/infrastructure/time-converter';

describe('Time Converter', () => {
  it('should be defined', () => {
    const timeConverter: TimeConverter = new TimeConverter();
    expect(timeConverter).toBeDefined();
  });

  describe('localStringTimeToUtcStringTime', () => {
    it('should convert a paris time to utc time with dst', () => {
      const timeConverter: TimeConverter = new TimeConverter();
      const parisTime = '08:00';
      const utcDatetime = timeConverter.localStringTimeToUtcStringTime(
        parisTime,
        'Europe/Paris',
      );
      expect(utcDatetime).toBe('07:00');
    });
    it('should return undefined if time is invalid', () => {
      const timeConverter: TimeConverter = new TimeConverter();
      const parisTime = '28:00';
      const utcDatetime = timeConverter.localStringTimeToUtcStringTime(
        parisTime,
        'Europe/Paris',
      );
      expect(utcDatetime).toBeUndefined();
    });
    it('should return undefined if time is undefined', () => {
      const timeConverter: TimeConverter = new TimeConverter();
      const parisTime = undefined;
      const utcDatetime = timeConverter.localStringTimeToUtcStringTime(
        parisTime,
        'Europe/Paris',
      );
      expect(utcDatetime).toBeUndefined();
    });
    it('should return undefined if timezone is invalid', () => {
      const timeConverter: TimeConverter = new TimeConverter();
      const fooBarTime = '08:00';
      const utcDatetime = timeConverter.localStringTimeToUtcStringTime(
        fooBarTime,
        'Foo/Bar',
      );
      expect(utcDatetime).toBeUndefined();
    });
    it('should return undefined if timezone is undefined', () => {
      const timeConverter: TimeConverter = new TimeConverter();
      const fooBarTime = '08:00';
      const utcDatetime = timeConverter.localStringTimeToUtcStringTime(
        fooBarTime,
        undefined,
      );
      expect(utcDatetime).toBeUndefined();
    });
  });

  // describe('utcDatetimeToLocalTime', () => {
  //   it('should convert an utc datetime isostring to a paris local time', () => {
  //     const timeConverter: TimeConverter = new TimeConverter();
  //     const utcDatetimeIsostring = '2023-06-22T06:25:00.000Z';
  //     const parisTime = timeConverter.utcDatetimeToLocalTime(
  //       utcDatetimeIsostring,
  //       'Europe/Paris',
  //     );
  //     expect(parisTime).toBe('08:25');
  //   });
  //   it('should return undefined if isostring input is invalid', () => {
  //     const timeConverter: TimeConverter = new TimeConverter();
  //     const utcDatetimeIsostring = 'not_an_isostring';
  //     const parisTime = timeConverter.utcDatetimeToLocalTime(
  //       utcDatetimeIsostring,
  //       'Europe/Paris',
  //     );
  //     expect(parisTime).toBeUndefined();
  //   });
  //   it('should return undefined if timezone input is invalid', () => {
  //     const timeConverter: TimeConverter = new TimeConverter();
  //     const utcDatetimeIsostring = '2023-06-22T06:25:00.000Z';
  //     const parisTime = timeConverter.utcDatetimeToLocalTime(
  //       utcDatetimeIsostring,
  //       'Foo/Bar',
  //     );
  //     expect(parisTime).toBeUndefined();
  //   });
  // });
});
